@@ -1,8 +1,4 @@
-if [ -x /usr/bin/gtk-update-icon-cache.exe ]
-then
-    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
-fi
-
+rm -f /usr/share/icons/hicolor/icon-theme.cache
 export GCONF_CONFIG_SOURCE="xml:merged:/etc/gconf/gconf.xml.defaults"
 /usr/bin/gconftool-2 --makefile-install-rule /etc/gconf/schemas/guake.schemas > /dev/null 2>&1
 
